macro_rules! resolve_object_ref {
($self:expr, $refs:expr) => { ... };
}Expand description
Resolves an object ref if the object is a reference (LoadRef or StoreRef). If not, it returns the object itself.
macro_rules! resolve_object_ref {
($self:expr, $refs:expr) => { ... };
}Resolves an object ref if the object is a reference (LoadRef or StoreRef). If not, it returns the object itself.